@@ -1,5 +1,5 @@
 from paypalrestsdk.api         import Api, set_config
-from paypalrestsdk.payments    import Payment, Sale
+from paypalrestsdk.payments    import Payment, Sale, Refund
 from paypalrestsdk.vault       import CreditCard
 from paypalrestsdk.exceptions  import *
 from paypalrestsdk.version     import __version__
